Interactive
===========

Functions reference
-------------------

.. autofunction:: diofant.interactive.printing.init_printing
.. autofunction:: diofant.interactive.session.init_ipython_session

AST Transformers
----------------

.. autoclass:: diofant.interactive.session.IntegerWrapper
.. autoclass:: diofant.interactive.session.AutomaticSymbols
